==> apo-ws-client-6.00.10.3-sources.jar: fr/univlorraine/apowsclient/pjOpi/RecupererPiecesJustificativesOPIWSResponse.java <==

package fr.univlorraine.apowsclient.pjOpi;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="PjOpiRetourDTO" type="{PjOpiRetourDTO.opipj.dto.transverse.commun.apogee.education.gouv}PjOpiRetourDTO"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "pjOpiRetourDTO"
})
@XmlRootElement(name = "recupererPiecesJustificativesOPIWSResponse", namespace = "gouv.education.apogee.commun.servicesmetiers.PjOpiMetier_16012017")
public class RecupererPiecesJustificativesOPIWSResponse {

    @XmlElement(name = "PjOpiRetourDTO", required = true)
    protected PjOpiRetourDTO pjOpiRetourDTO;

    /**
     * Obtient la valeur de la propriété pjOpiRetourDTO.
     * 
     * @return
     *     possible object is
     *     {@link PjOpiRetourDTO }
     *     
     */
    public PjOpiRetourDTO getPjOpiRetourDTO() {
        return pjOpiRetourDTO;
    }

    /**
     * Définit la valeur de la propriété pjOpiRetourDTO.
     * 
     * @param value
     *     allowed object is
     *     {@link PjOpiRetourDTO }
     *     
     */
    public void setPjOpiRetourDTO(PjOpiRetourDTO value) {
        this.pjOpiRetourDTO = value;
    }

}

==> apo-ws-client-6.00.50.1-sources.jar: fr/univlorraine/apowsclient/pjOpi/RecupererPiecesJustificativesOPIWSResponse.java <==

package fr.univlorraine.apowsclient.pjOpi;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="PjOpiRetourDTO" type="{PjOpiRetourDTO.opipj.dto.transverse.commun.apogee.education.gouv}PjOpiRetourDTO"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "pjOpiRetourDTO"
})
@XmlRootElement(name = "recupererPiecesJustificativesOPIWSResponse", namespace = "gouv.education.apogee.commun.servicesmetiers.PjOpiMetier")
public class RecupererPiecesJustificativesOPIWSResponse {

    @XmlElement(name = "PjOpiRetourDTO", required = true)
    protected PjOpiRetourDTO pjOpiRetourDTO;

    /**
     * Obtient la valeur de la propriété pjOpiRetourDTO.
     * 
     * @return
     *     possible object is
     *     {@link PjOpiRetourDTO }
     *     
     */
    public PjOpiRetourDTO getPjOpiRetourDTO() {
        return pjOpiRetourDTO;
    }

    /**
     * Définit la valeur de la propriété pjOpiRetourDTO.
     * 
     * @param value
     *     allowed object is
     *     {@link PjOpiRetourDTO }
     *     
     */
    public void setPjOpiRetourDTO(PjOpiRetourDTO value) {
        this.pjOpiRetourDTO = value;
    }

}
